@@ -1,7 +1,7 @@
 #!/bin/sh
 
 ## live-build(7) - System Build Scripts
-## Copyright (C) 2006-2013 Daniel Baumann <daniel@debian.org>
+## Copyright (C) 2006-2014 Daniel Baumann <mail@daniel-baumann.ch>
 ##
 ## This program comes with ABSOLUTELY NO WARRANTY; for details see COPYING.
 ## This is free software, and you are welcome to redistribute it
@@ -16,7 +16,7 @@ Get_conffiles ()
 	else
 		for FILE in ${@}
 		do
-			FILES="${FILES} ${FILE} ${FILE}.${LB_ARCHITECTURES} ${FILE}.${DISTRIBUTION}"
+			FILES="${FILES} ${FILE} ${FILE}.${LIVE_IMAGE_ARCHITECTURE} ${FILE}.${DISTRIBUTION}"
 			FILES="${FILES} config/$(echo ${PROGRAM} | sed -e 's|^lb_||')"
 			FILES="${FILES} config/$(echo ${PROGRAM} | sed -e 's|^lb_||').${ARCHITECTURE}"
 			FILES="${FILES} config/$(echo ${PROGRAM} | sed -e 's|^lb_||').${DISTRIBUTION}"
